
#region Using declarations
using System;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.ComponentModel;
using System.Xml.Serialization;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    [Description("")]
    public class NSL_TicksPerBar : Indicator
    {
        #region Variables
		private double barsize;
		private int tickcount = 0;
		#endregion

		#region Initialize
        /// <summary>
        /// This method is used to configure the strategy and is called once before any strategy method is called.
        /// </summary>
        protected override void Initialize()
        {
			base.Name = "NSL_TicksPerBar";
			Add(new Plot(new Pen(Color.Green, 16), PlotStyle.Bar, "T&S"));
			Add(new Line(Color.DarkGray, 0, "Zero line"));
			Add(Instrument.FullName, PeriodType.Tick,  1, MarketDataType.Last);
			CalculateOnBarClose = true;
			Overlay				= false;
            PriceTypeSupported	= false;
			AutoScale			= true;
			DrawOnPricePanel 	= false;
			PlotsConfigurable = false;
			LinesConfigurable = false;
		}
		#endregion

		#region OnBarUpdate
        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if(BarsInProgress == 1)
			{
				tickcount++;
			}
			
			if(BarsInProgress == 0)
			{
				if(FirstTickOfBar)
				{
					try
					{
						string textToDraw;
							
						if(Closes[0][0] > Opens[0][0])
						{
							barsize = (Closes[0][0] - Opens[0][0])/TickSize;
							
							textToDraw = Instrument.MasterInstrument.Round2TickSize(barsize).ToString()+"S"
								+ "\r\n" +tickcount.ToString()+"T";
							
							DrawText(CurrentBar.ToString(), true, textToDraw, 0, 2 + barsize, 0, _nmup, new Font("Arial", size_), StringAlignment.Center, Color.Transparent, Color.Transparent, 20);
							Value.Set(barsize);
							PlotColors[0][0] = _nmup;
							Plots[0].Pen.Width = width;
						}
						else if(Closes[0][0] < Opens[0][0])
						{
							barsize = (Opens[0][0] - Closes[0][0])/TickSize;
							textToDraw = Instrument.MasterInstrument.Round2TickSize(barsize).ToString()+"S"
								+ "\r\n" +tickcount.ToString()+"T";
							
							DrawText(CurrentBar.ToString(), true, textToDraw, 0, -1 - (barsize), 0, _nmdown, new Font("Arial", size_), StringAlignment.Center, Color.Transparent, Color.Transparent, 20);
							Value.Set(-barsize);
							PlotColors[0][0] = _nmdown;
							Plots[0].Pen.Width = width;
						}
						else 
						{
							Value.Set(0);
							PlotColors[0][0] = Color.Black;
						}
					}
					catch
					{
						
					}
					tickcount = 0;
				}
			}
		}
		#endregion
		
        #region Properties
		public override string ToString()
		{
			base.Name = "";
			return "";
		}
		
		[Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries T_Svalue
        {
            get { return Value; }
        }
		
		private int	size_ = 8;
        [Description("")]
        [Category("Plots")]
        [Gui.Design.DisplayNameAttribute("\tText Size")]
        public int _Size
        {
            get { return size_; }
            set { size_ = value; }
        }
		
		private Color _nmdown = Color.Red;
		[Description("")]
        [Category("Plots")]
        [Gui.Design.DisplayName("Sell")]
        public Color Nmdown
        {
            get { return _nmdown; }
            set { _nmdown = value; }
        }

        [Browsable(false)]
        public string NmdownSerialize
        {
            get { return Gui.Design.SerializableColor.ToString(_nmdown); }
            set { _nmdown = Gui.Design.SerializableColor.FromString(value); }
        }
		
		private Color _nmup = Color.Green;
        [Description("")]
        [Category("Plots")]
        [Gui.Design.DisplayName("Buy")]
        public Color Nmup
        {
            get { return _nmup; }
            set { _nmup = value; }
        }

        [Browsable(false)]
        public string NmupSerialize
        {
            get { return Gui.Design.SerializableColor.ToString(_nmup); }
            set { _nmup = Gui.Design.SerializableColor.FromString(value); }
        }
		
		private int	width = 10;
        [Description("")]
      	[Category("Plots")]
        [Gui.Design.DisplayNameAttribute("Bar Width")]
        public int Width
        {
            get { return width; }
            set { width = value; }
        }
		#endregion
	}
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private NSL_TicksPerBar[] cacheNSL_TicksPerBar = null;

        private static NSL_TicksPerBar checkNSL_TicksPerBar = new NSL_TicksPerBar();

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public NSL_TicksPerBar NSL_TicksPerBar()
        {
            return NSL_TicksPerBar(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public NSL_TicksPerBar NSL_TicksPerBar(Data.IDataSeries input)
        {
            if (cacheNSL_TicksPerBar != null)
                for (int idx = 0; idx < cacheNSL_TicksPerBar.Length; idx++)
                    if (cacheNSL_TicksPerBar[idx].EqualsInput(input))
                        return cacheNSL_TicksPerBar[idx];

            lock (checkNSL_TicksPerBar)
            {
                if (cacheNSL_TicksPerBar != null)
                    for (int idx = 0; idx < cacheNSL_TicksPerBar.Length; idx++)
                        if (cacheNSL_TicksPerBar[idx].EqualsInput(input))
                            return cacheNSL_TicksPerBar[idx];

                NSL_TicksPerBar indicator = new NSL_TicksPerBar();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                NSL_TicksPerBar[] tmp = new NSL_TicksPerBar[cacheNSL_TicksPerBar == null ? 1 : cacheNSL_TicksPerBar.Length + 1];
                if (cacheNSL_TicksPerBar != null)
                    cacheNSL_TicksPerBar.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheNSL_TicksPerBar = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.NSL_TicksPerBar NSL_TicksPerBar()
        {
            return _indicator.NSL_TicksPerBar(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.NSL_TicksPerBar NSL_TicksPerBar(Data.IDataSeries input)
        {
            return _indicator.NSL_TicksPerBar(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.NSL_TicksPerBar NSL_TicksPerBar()
        {
            return _indicator.NSL_TicksPerBar(Input);
        }

        /// <summary>
        /// 
        /// </summary>
        /// <returns></returns>
        public Indicator.NSL_TicksPerBar NSL_TicksPerBar(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.NSL_TicksPerBar(input);
        }
    }
}
#endregion
